pub struct WorkerHandle { /* private fields */ }Expand description
Handle to a worker registered on a SharedRuntime.
This handle can be used to stop the worker.
Warning
If every clone of this handle is dropped without calling WorkerHandle::stop, the worker
remains registered on the SharedRuntime and can only be torn down by shutting the
runtime down. Workers are expected to detect that their input channel has been closed and
park themselves to avoid spinning, but they will not be freed until the runtime stops.
Implementations
Sourceimpl WorkerHandle
impl WorkerHandle
Sourcepub async fn stop(self) -> Result<(), WorkerHandleError>
pub async fn stop(self) -> Result<(), WorkerHandleError>
Stop the worker and execute the shutdown logic.
Errors
Returns an error if the worker has already been stopped.
Cancel safety
This function is NOT cancel safe and shouldn’t be called in Worker::trigger. If cancelled, the stopped worker can end up in an invalid state if a fork occurs while stopping.